@@ -13,10 +13,11 @@ from pytest_alembic.plugin.error import AlembicTestFailure
 from pytest_alembic.runner import MigrationContext
 from sqlmodel import SQLModel
 
+from lndb_setup._delete import delete
 from lndb_setup._init_instance import init
 
 
-def get_migration_config(schema_package_loc, target_metadata=None, **kwargs):
+def get_migration_config(schema_package_loc, *, target_metadata=None, **kwargs):
     if target_metadata is None:
         target_metadata = SQLModel.metadata
     target_metadata.naming_convention = {
@@ -38,7 +39,7 @@ def get_migration_config(schema_package_loc, target_metadata=None, **kwargs):
 
 def get_migration_context(schema_package, db, include_schemas=None):
     engine = sa.create_engine(db)
-    config = get_migration_config(schema_package, include_schemas)
+    config = get_migration_config(schema_package, include_schemas=include_schemas)
     command_executor = CommandExecutor.from_config(config)
     command_executor.configure(connection=engine)
     migration_context = MigrationContext.from_config(
@@ -74,12 +75,12 @@ def model_definitions_match_ddl(schema_package, db=None, dialect_name="sqlite"):
     if db is None and dialect_name == "sqlite":
         db = "sqlite:///testdb/testdb.lndb"
         # need to call init to reload schema
-        init(storage="testdb", migrate=False)
+        init(storage="testdb", _migrate=False)
     elif db is None and dialect_name == "postgresql":
         # requires postgres has been set up through _nox_tools
         db = "postgresql://postgres:pwd@0.0.0.0:5432/pgtest"
         # need to call init to reload schema
-        init(db=db, storage="pgtest", migrate=False)
+        init(db=db, storage="pgtest", _migrate=False)
     elif db is None:
         raise NotImplementedError(
             "Only sqlite and postgres test databases are implemented."
@@ -94,6 +95,9 @@ def model_definitions_match_ddl(schema_package, db=None, dialect_name="sqlite"):
     execute_model_definitions_match_ddl(migration_context)
     if dialect_name == "postgresql":
         run("docker stop pgtest && docker rm pgtest", shell=True)
+        delete("pgtest")
+    else:
+        delete("testdb")
 
 
 def execute_model_definitions_match_ddl(alembic_runner):
